<?php

class OF_Admin_Settings {
	
	private $plugin_name;
	
	private $version;
	
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}
	
	public function setup_plugin_options_menu() {

		add_plugins_page(
			'Elegant Authentication',
			'Elegant Authentication',
			'manage_options',
			'temaof_elegant_auth_options',
			array( $this, 'render_settings_page_content')
		);
	}

	public function default_login_options() {
		$defaults = array(
			'login_redirect_url'	=>	get_home_url(),
			'login_title'			=>	'Welcome Back',
			'login_description'		=>	'To keep connected with us please login with your personal information. 🎉🎉🎉',
		);
		return $defaults;
	}


	public function default_register_options() {
		$defaults = array(
			'register_redirect_url'	=>	get_home_url(),
			'register_description'		=>	'Join to a workplace to over 12 milion influencers.',
		);
		return $defaults;
	}
	

	public function default_logout_options() {
		$defaults = array(
			'logout_redirect_url'		=> get_home_url(),
			'logout_description'		=>	'',
		);
		return  $defaults;
	}
	
	public function default_forgot_options() {
		$defaults = array(
			'forgot_description'		=>	'Enter your email below to receive your password reset instructions.',
		);
		return  $defaults;
	}

	public function default_cover_options() {
		$defaults = array(
			'cover_image_url'		=>	plugin_dir_url($this->plugin_name.'/public').'public/images/fox.jpg',
			'cover_html'			=> 	'<h1 class="pt-4 mt-4" style="color: #ffffff">Team OF</h1>'
		);
		return  $defaults;
	}

	public function default_captcha_options() {
		$defaults = array(
			'enabled_captcha'		=>	'',
			'captcha_title'			=> 	'Prove you are not robot'
		);
		return  $defaults;
	}

	public function render_settings_page_content( $active_tab = '' ) { ?>

		<div class="wrap">

			<h2><?php _e( 'Elegant Authentication', 'teamof-translate' ); ?></h2>
			
			<?php settings_errors(); ?>

			<?php if(isset($_GET['tab'])) $active_tab = $_GET['tab']; else  $active_tab = 'login_options'; ?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=temaof_elegant_auth_options&tab=login_options" class="nav-tab <?php echo $active_tab == 'login_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Login Options', 'teamof-translate' ); ?></a>
				<a href="?page=temaof_elegant_auth_options&tab=register_options" class="nav-tab <?php echo $active_tab == 'register_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Register Options', 'teamof-translate' ); ?></a>
				<a href="?page=temaof_elegant_auth_options&tab=logout_options" class="nav-tab <?php echo $active_tab == 'logout_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Logout Options', 'teamof-translate' ); ?></a>
				<a href="?page=temaof_elegant_auth_options&tab=forgot_options" class="nav-tab <?php echo $active_tab == 'forgot_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Forgot Options', 'teamof-translate' ); ?></a>
				<a href="?page=temaof_elegant_auth_options&tab=cover_options" class="nav-tab <?php echo $active_tab == 'cover_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Cover Options', 'teamof-translate' ); ?></a>
				<a href="?page=temaof_elegant_auth_options&tab=captcha_options" class="nav-tab <?php echo $active_tab == 'captcha_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Google reCAPTHA', 'teamof-translate' ); ?></a>
			</h2>

			<form method="post" action="options.php">
				<?php

					if( $active_tab == 'login_options' ) {
						settings_fields( 'teamof_elegant_login_options' );
						do_settings_sections( 'teamof_elegant_login_options' );
					} elseif( $active_tab == 'register_options' ) {
						settings_fields( 'teamof_elegant_register_options' );
						do_settings_sections( 'teamof_elegant_register_options' );
					} elseif( $active_tab == 'logout_options' ) {
						settings_fields( 'teamof_elegant_logout_options' );
						do_settings_sections( 'teamof_elegant_logout_options' );
					} 
					elseif( $active_tab == 'forgot_options' ) {
						settings_fields( 'teamof_elegant_forgot_options' );
						do_settings_sections( 'teamof_elegant_forgot_options' );
					}
					elseif( $active_tab == 'cover_options' ) {
						settings_fields( 'teamof_elegant_cover_options' );
						do_settings_sections( 'teamof_elegant_cover_options' );
					}
					elseif( $active_tab == 'captcha_options' ) {
						settings_fields( 'teamof_elegant_captcha_options' );
						do_settings_sections( 'teamof_elegant_captcha_options' );
					} 

					submit_button();
				?>
			</form>

		</div>
	<?php
	}

	public function add_setting_callback() {
		return;
	}

	public function initialize_login_options() {

		if( false == get_option( 'teamof_elegant_login_options' ) ) {
			$default_array = $this->default_login_options();
			add_option( 'teamof_elegant_login_options', $default_array );
		}
		add_settings_section(
			'login_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_login_options'
		);

		add_settings_field(
			'login_redirect_url',
			__( 'Login Redirect URL', 'teamof-translate' ),
			array( $this, 'login_redirect_url'),
			'teamof_elegant_login_options',
			'login_settings_section'
		);
		add_settings_field(
			'login_title',
			__( 'Login Title', 'teamof-translate' ),
			array( $this, 'login_title'),
			'teamof_elegant_login_options',
			'login_settings_section'
		);
		add_settings_field(
			'login_description',
			__( 'Login Description', 'teamof-translate' ),
			array( $this, 'login_description'),
			'teamof_elegant_login_options',
			'login_settings_section'
		);
		register_setting(
			'teamof_elegant_login_options',
			'teamof_elegant_login_options'
		);
	}

	public function initialize_register_options() {

		if( false == get_option( 'teamof_elegant_register_options' ) ) {
			$default_array = $this->default_register_options();
			update_option( 'teamof_elegant_register_options', $default_array );
		}
		add_settings_section(
			'register_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_register_options'
		);
		add_settings_field(
			'register_redirect_url',
			'Register Redirect URL',
			array( $this, 'register_redirect_url'),
			'teamof_elegant_register_options',
			'register_settings_section'
		);
		add_settings_field(
			'register',
			'Register Description',
			array( $this, 'register_description'),
			'teamof_elegant_register_options',
			'register_settings_section'
		);
		register_setting(
			'teamof_elegant_register_options',
			'teamof_elegant_register_options'
		);
	}

	public function initialize_logout_options() {

		if( false == get_option( 'teamof_elegant_logout_options' ) ) {
			$default_array = $this->default_register_options();
			update_option( 'teamof_elegant_logout_options', $default_array );
		}
		add_settings_section(
			'logout_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_logout_options'
		);
		add_settings_field(
			'logout_redirect_url',
			'Logout Redirect URL',
			array( $this, 'logout_redirect_url'),
			'teamof_elegant_logout_options',
			'logout_settings_section'
		);
		add_settings_field(
			'logout_description',
			'Logout Description',
			array( $this, 'logout_description'),
			'teamof_elegant_logout_options',
			'logout_settings_section'
		);
		register_setting(
			'teamof_elegant_logout_options',
			'teamof_elegant_logout_options'
		);

	}

	public function initialize_forgot_options() {

		if( false == get_option( 'teamof_elegant_forgot_options' ) ) {
			$default_array = $this->default_forgot_options();
			update_option( 'teamof_elegant_forgot_options', $default_array );
		}
		add_settings_section(
			'forgot_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_forgot_options'
		);
		add_settings_field(
			'forgot_description',
			'Forgot Description',
			array( $this, 'forgot_description'),
			'teamof_elegant_forgot_options',
			'forgot_settings_section'
		);
		register_setting(
			'teamof_elegant_forgot_options',
			'teamof_elegant_forgot_options'
		);

	}

	public function initialize_cover_options() {

		if( false == get_option( 'teamof_elegant_cover_options' ) ) {
			$default_array = $this->default_cover_options();
			update_option( 'teamof_elegant_cover_options', $default_array );
		}
		add_settings_section(
			'cover_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_cover_options'
		);
		add_settings_field(
			'cover_image_url',
			'Cover Image URL',
			array( $this, 'cover_image_url'),
			'teamof_elegant_cover_options',
			'cover_settings_section'
		);
		add_settings_field(
			'cover_html',
			'Cover HTML',
			array( $this, 'cover_html'),
			'teamof_elegant_cover_options',
			'cover_settings_section'
		);
		register_setting(
			'teamof_elegant_cover_options',
			'teamof_elegant_cover_options'
		);

	}

	public function initialize_captcha_options() {

		if( false == get_option( 'teamof_elegant_captcha_options' ) ) {
			$default_array = $this->default_captcha_options();
			update_option( 'teamof_elegant_captcha_options', $default_array );
		}
		add_settings_section(
			'captcha_settings_section',
			__( ' ', 'teamof-translate' ),
			array( $this, 'add_setting_callback'),
			'teamof_elegant_captcha_options'
		);
		add_settings_field(
			'enabled_captcha',
			'Enable Google reCAPTCHA',
			array( $this, 'enabled_captcha'),
			'teamof_elegant_captcha_options',
			'captcha_settings_section'
		);
		add_settings_field(
			'captcha_title',
			'Text Holder',
			array( $this, 'captcha_title'),
			'teamof_elegant_captcha_options',
			'captcha_settings_section'
		);
		add_settings_field(
			'google_site_key',
			'Google Site Key',
			array( $this, 'google_site_key'),
			'teamof_elegant_captcha_options',
			'captcha_settings_section'
		);
		register_setting(
			'teamof_elegant_captcha_options',
			'teamof_elegant_captcha_options'
		);

	}

	public function login_redirect_url($args) {

		$options = get_option('teamof_elegant_login_options');

		$html = '<input type="text" id="login_redirect_url" name="teamof_elegant_login_options[login_redirect_url]" value="'.$options['login_redirect_url'].'" size="35"/>';

        echo $html;

	}

	public function login_title($args) {

		$options = get_option('teamof_elegant_login_options');

		$html = '<input type="text" id="login_title" name="teamof_elegant_login_options[login_title]" value="'.$options['login_title'].'" size="35"/>';

        echo $html;

	}

	public function login_description($args) {

		$options = get_option('teamof_elegant_login_options');

		$html = '<textarea id="login_description" name="teamof_elegant_login_options[login_description]" rows="10" cols="50">'.$options['login_description'].'</textarea>';

        echo $html;

	}

	
	public function register_redirect_url() {

		$options = get_option( 'teamof_elegant_register_options' );
		
		echo '<input type="text" id="register_redirect_url" name="teamof_elegant_register_options[register_redirect_url]" value="'.$options['register_redirect_url'].'" size="35"/>';

	}
	
	public function register_description() {

		$options = get_option( 'teamof_elegant_register_options' );
		
		echo '<textarea id="register_description" name="teamof_elegant_register_options[register_description]" rows="10" cols="50">'.$options['register_description'].'</textarea>';

	}

	public function logout_redirect_url() {

		$options = get_option( 'teamof_elegant_logout_options' );
		
		echo '<input type="text" id="logout_redirect_url" name="teamof_elegant_logout_options[logout_redirect_url]" value="'.$options['logout_redirect_url'].'" size="35"/>';

	}
	
	public function logout_description() {

		$options = get_option( 'teamof_elegant_logout_options' );
		
		echo '<textarea id="logout_description" name="teamof_elegant_logout_options[logout_description]" rows="10" cols="50">'.$options['logout_description'].'</textarea>';

	}

	public function forgot_description() {

		$options = get_option( 'teamof_elegant_forgot_options' );
		
		echo '<textarea id="forgot_description" name="teamof_elegant_forgot_options[forgot_description]" rows="10" cols="50">'.$options['forgot_description'].'</textarea>';

	}

	public function cover_image_url() {

		$options = get_option( 'teamof_elegant_cover_options' );

		echo '<input type="text" id="cover_image_url" name="teamof_elegant_cover_options[cover_image_url]" value="'.$options['cover_image_url'].'" size="35"/>';

	}

	public function cover_html() {

		$options = get_option( 'teamof_elegant_cover_options' );

		echo '<textarea id="cover_html" name="teamof_elegant_cover_options[cover_html]" rows="10" cols="50">'.$options['cover_html'].'</textarea>';

	}

	public function enabled_captcha($args) {

		$options = get_option( 'teamof_elegant_captcha_options' );

		echo '<input id="enabled_captcha" type="checkbox" name="teamof_elegant_captcha_options[enabled_captcha]" value="1" ' . checked( 1, isset( $options['enabled_captcha'] ) ? $options['enabled_captcha'] : 0, false ) . '/>';
		
	}

	public function captcha_title() {

		$options = get_option( 'teamof_elegant_captcha_options' );

		echo '<input type="text" id="teamof_captcha_title" name="teamof_elegant_captcha_options[captcha_title]" value="'.$options['captcha_title'].'" size="35"/>';

	}

	public function google_site_key() {

		$options = get_option( 'teamof_elegant_captcha_options' );

		echo '<input type="text" id="teamof_google_site_key" name="teamof_elegant_captcha_options[google_site_key]" value="'.$options['google_site_key'].'" size="35"/>';

	}

	public function sanitize_social_options( $input ) {

		$output = array();

		foreach( $input as $key => $val ) {
			if( isset ( $input[$key] ) ) {
				$output[$key] = esc_url_raw( strip_tags( stripslashes( $input[$key] ) ) );
			}
		}

		return apply_filters( 'sanitize_social_options', $output, $input );
	}

	public function validate_input_examples($input) {

		$output = array();

		foreach( $input as $key => $value ) {

			if( isset( $input[$key] ) ) {

				$output[$key] = strip_tags(stripslashes($input[ $key ]));

			}

		}

		return apply_filters( 'validate_input_examples', $output, $input );
	}

}