<?php

class OF_Elegant_Auth {

	
	protected $loader;


	protected $plugin_name;

	
	protected $version;

	
	public function __construct() {

		$this->plugin_name = 'teamof-elegant-authentication';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - OF_Elegant_Auth_Plugin_Loader. Orchestrates the hooks of the plugin.
	 * - Wppb_Demo_Plugin_i18n. Defines internationalization functionality.
	 * - TeamOF_Elegant_Auth_Admin. Defines all hooks for the admin area.
	 * - OF_Elegant_Modal_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-of-elegant-auth-plugin-loader.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-of-elegant-auth-plugin-admin.php';


		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-of-elegant-auth-plugin-public.php';

		$this->loader = new OF_Elegant_Auth_Plugin_Loader();

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new TeamOF_Elegant_Auth_Admin( $this->get_plugin_name(), $this->get_version() );
		$plugin_settings = new OF_Admin_Settings( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'admin_menu', $plugin_settings, 'setup_plugin_options_menu' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_login_options' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_register_options' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_forgot_options' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_logout_options' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_cover_options' );
		$this->loader->add_action( 'admin_init', $plugin_settings, 'initialize_captcha_options' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new OF_Elegant_Modal_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'wp_ajax_get_login_ajax_request', $plugin_public, 'get_login_ajax_request' );
		$this->loader->add_action( 'wp_ajax_nopriv_get_login_ajax_request', $plugin_public, 'get_login_ajax_request' );
		$this->loader->add_action( 'wp_ajax_get_register_ajax_request', $plugin_public, 'get_register_ajax_request' );
		$this->loader->add_action( 'wp_ajax_nopriv_get_register_ajax_request', $plugin_public, 'get_register_ajax_request' );
		$this->loader->add_action( 'wp_ajax_get_forgot_ajax_request', $plugin_public, 'get_forgot_ajax_request' );
		$this->loader->add_action( 'wp_ajax_nopriv_get_forgot_ajax_request', $plugin_public, 'get_forgot_ajax_request' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    OF_Elegant_Auth_Plugin_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
