<?php

class OF_Elegant_Modal_Public {

	
	private $plugin_name;


	private $version;


	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;

		$this->version = $version;

		add_shortcode( 'teamof_auth',array( $this, 'of_modal_form_shortcode' ));

		add_action('wp_footer', array($this, 'html_modal'), 0);

	}

	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/elegant-modal-auth.css', array(), $this->version, 'all' );

	}

	public function enqueue_scripts() {

		wp_enqueue_script(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'js/elegant-modal-auth.js',
			array('jquery')
		);

		wp_localize_script(
			$this->plugin_name,
			'of_ajax_obj',
			array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) )
		);

	}

	public function of_modal_form_shortcode( $atts , $content = null ) {

		$attributes = shortcode_atts([
			'type' => 'button',
			'authenticated_text' => 'Login',
			'unauthenticated_text' => 'Logout'
		], $atts);


		if('link' == $attributes['type']) {
			$html = '<a data-toggle="modal" data-target="#of_elegant_modal" href="javascript:void(0);">'.((is_user_logged_in()) ? $attributes['unauthenticated_text'] : $attributes['authenticated_text']).'</a>';
		}

		if('button' == $attributes['type']) {
			$html = '<div class="btn btn-primary open-btn" data-toggle="modal" data-target="#of_elegant_modal">'.((is_user_logged_in()) ? $attributes['unauthenticated_text'] : $attributes['authenticated_text']).'</div>';
		}

		return $html;

	}

	
	public function html_modal() {
		
		$cover_options = get_option('teamof_elegant_cover_options');

		$login_options = get_option('teamof_elegant_login_options');

		$register_options = get_option('teamof_elegant_register_options');

		$logout_options = get_option('teamof_elegant_logout_options');

		$forgot_options = get_option('teamof_elegant_forgot_options');

        $allowed_registration = get_option('users_can_register');

		$captcha_options = get_option('teamof_elegant_captcha_options');

        $html = '
			<div class="modal of-elegant-modal" tabindex="-1" role="dialog" id="of_elegant_modal">
				<div class="modal-dialog modal-lg modal-dialog-centered" role="document">
					<div class="modal-content">
						<div class="container-fluid">
							<div class="row">
							    <div class="col-lg-6 p-4 of-intro-container" style="background-image: url('.$cover_options["cover_image_url"].')">
								    '.$cover_options["cover_html"].'
                                </div> <!--End .col-lg-6 -->
                                <div class="col-lg-6 p-0">
                                    <div class="py-4 of-login-container of-show">
										<h3 class="pt-2">'.$login_options['login_title'].'</h3>
                                        <p class="of-form-description">'.$login_options['login_description'].'</p>
                                            <div class="form-group">
                                                <label for="login-email">Username</label>
                                                <div class="of-input-container">
                                                    <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/user.svg"></div>
                                                    <input type="text" class="form-control of-login-username" name="of-login-username" placeholder="Username" spellcheck="false">
                                                    <div class="of-input-validation login-username-validation"></div>
                                                </div>
                                            </div>
                                            <div class="form-group">
                                                <label for="login-password">Password</label>
                                                <div class="of-input-container">
                                                    <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/lock.svg"></div>
                                                    <input type="password" name="of-login-password" class="form-control of-login-password" id="login-password" placeholder="Password" spellcheck="false">
                                                    <div class="of-input-validation lpassword-toggle-btn show-password"></div>
                                                </div>
                                            </div>
                                            <div class="container mb-4 pt-3">
                                                <div class="row">
                                                    <div class="col-6">
                                                        <label class="control control--checkbox">First checkbox
                                                            <input type="checkbox" checked="checked"/>
                                                            <div class="control__indicator"></div>
                                                        </label>
                                                    </div> <!-- End .col-6 -->
                                                    <div class="col-6 text-right">
                                                        <a class="of-forgot-password of-forgot-link" href="#">Forgot password?</a>
                                                    </div> <!-- End .col-6 -->
                                                </div> <!-- End .row -->
                                            </div> <!-- End .container -->

                                            <div class="form-group mb-4 of-login-btn-container">
                                                <button type="submit" class="btn btn-block of-btn of-login-btn btn-primary" of-captcha="'.(($captcha_options["enabled_captcha"] == 1) ? "captcha" : "off").'" disabled>Sign In</button>
                                            </div> 
                                        '.(($allowed_registration) ? '<a class="of-signup-link of-toggle-link pb-2" href="#">Dont have an account yet? Sign Up!</a>' : '').'
                                    </div> <!--End  .col-lg-6 .of-login-container -->
                                    <div class="py-4 of-forgot-container">
                                            <h3 class="pt-2 pb-3">Forgot your password?</h3>
                                            <p class="of-form-description">'.$forgot_options['forgot_description'].'</p>
                                                <div class="form-group">
                                                    <label for="login-email">Email address</label>
                                                    <div class="of-input-container">
                                                        <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/mail.svg"></div>
                                                        <input type="text" class="form-control of-email-validate of-forgot-email" id="of-forgot-email" name="of-forgot-email" placeholder="Email" spellcheck="false">
                                                        <div class="of-input-validation"></div>
                                                    </div>
                                                </div>
                                                <div class="form-group">
                                                    <button type="submit" class="btn of-block-btn of-btn of-forgot-btn btn-primary btn-block" disabled>Send Password</button>
                                                </div> <!-- End .container -->
                                            <a class="of-forgot-link pb-2" href="#">Back</a>
                                        </div> <!--End  .col-lg-6 .of-forgot-container -->
                                    <div class="py-4 of-register-container">
                                        <p class="of-form-description pb-2"><b>'.$register_options['register_description'].'</b></p>
                                            <div class="form-group">
                                                <label for="of-register-username">Username</label>
                                                <div class="of-input-container">
                                                    <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/user.svg"></div>
                                                    <input type="text" class="form-control" name="of-register-username" id="of-register-username" placeholder="Username" spellcheck="false">
                                                    <div class="of-input-validation register-username-validation"></div>
                                                </div>
                                            </div>
                                            <div class="form-group">
                                                <label for="of-register-email">Email</label>
                                                <div class="of-input-container">
                                                    <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/mail.svg"></div>
                                                    <input type="text" class="form-control of-email-validate of-register-email" id="of-register-email" placeholder="Enter Email..." spellcheck="false">
                                                    <div class="of-input-validation"></div>
                                                </div>
                                            </div> <!--End .form-group -->
                                            <div class="form-group pr-0">
                                                <label for="of-register-password">Set Password</label>
                                                <div class="of-input-container">
                                                    <div class="of-input-icon"><img src="'.plugin_dir_url(__FILE__).'/images/lock.svg"></div>
                                                    <input type="password" name="of-register-password" class="form-control of-register-password" id="of-register-password" placeholder="Password" spellcheck="false">
                                                    <div class="of-input-validation rpassword-toggle-btn show-password"></div>
                                                </div>
                                            </div><!--End .form-group -->
                                            <div class="container-fluid of-validation-tips pb-4">
                                                <div class="row">
                                                    <div class="col-6 mb-3 tips of-lowercase-tip">
                                                        <span>One lowercase charactar</span>
                                                    </div>  <!--End .col-6 -->
                                                    <div class="col-6 mb-3 tips of-one-number-tip">
                                                        <span>One number</span>
                                                    </div>  <!--End .col-6 -->
                                                    <div class="col-6 tips of-uppercase-tip">
                                                        <span>One uppercase charactar</span>
                                                    </div>  <!--End .col-6 -->
                                                    <div class="col-6 tips of-8chars-tip">
                                                        <span>8 Charactar minimum</span>
                                                    </div>
                                                </div> <!--End .col-6 -->
                                            </div> <!--End .container-fluid -->
                                            <div class="form-group">
                                                <button type="submit" class="btn of-btn of-block-btn of-register-btn btn-primary btn-block" disabled>Get Started</button>
                                            </div> <!-- End .container -->
                                        <a class="of-signin-link of-toggle-link" href="#">Already have an account? Sign In!</a>
                                    </div> <!--End  .col-lg-6 .of-register-container -->
                                </div>
							</div> <!--End .row -->
						</div> <!--End .container-fluid -->
					</div> <!--End .modal-content -->
				</div> <!-- End .modal-dialog -->
            </div> <!-- End .modal -->
            
			<div class="of-captcha-container" id="teamof-captcha">
				<div class="of-captcha-wrapper">
					<div class="of-close-wrapper"><div class="of-close"></div></div>
					<h3>'.$captcha_options['captcha_title'].'</h3>
                	<div id="recaptcha" class="g-recaptcha" data-callback="teamof" data-sitekey="'.$captcha_options['google_site_key'].'"></div>
				</div>
			</div>';

		if(is_user_logged_in()) {

			global $current_user;

			$html = '
			<div class="modal of-elegant-modal" tabindex="-1" role="dialog" id="of_elegant_modal">
				<div class="modal-dialog modal-lg modal-dialog-centered" role="document">
					<div class="modal-content">
						<div class="container-fluid">
							<div class="row">
								<div class="col-lg-6 p-4 of-intro-container" style="background-image: url('.$cover_options["cover_image_url"].')">
									'.$cover_options["cover_html"].'
								</div> <!--End .col-lg-6 -->
								<div class="col-lg-6 py-4 of-logged-in of-show">
									<figure>
										<img src="'.get_avatar_url($current_user->user_email).'"/>
									</figure>
									<h4>Hello, '.$current_user->display_name.'</h4>
									<p>'.$logout_options['logout_description'].'</p>
									<div class="form-group mb-4 of-logout-btn-container">
										<a href="'.wp_logout_url($logout_options["logout_redirect_url"]).'" class="btn of-btn of-logout-btn btn-primary">Logout</a>
									</div> 
								</div> <!--End  .col-lg-6 .of-login-container -->
							</div> <!--End .row -->
						</div> <!--End .container-fluid -->
					</div> <!--End .modal-content -->
				</div> <!-- End .modal-dialog -->
			</div> <!-- End .modal -->';

		}

		echo $html;
	
	}

	public function get_login_ajax_request() {

		if(isset($_REQUEST) ) {
			
			$user = username_exists($_REQUEST['of-login-username']);

			if(!$user)
				wp_send_json_error([
					'message' => "User not found"
				]);

			$user_info = array();
			
			$user_info['user_login'] = $_REQUEST['of-login-username'];
			$user_info['user_password'] = $_REQUEST['of-login-password'];
			$user_info['remember'] = ($_REQUEST['of-remember'] == "true") ? true : false;

			$user_signon = wp_signon($user_info, false);

			if(is_wp_error($user_signon)) {
				wp_send_json_error([
					'message' => "Something wrong"
				]);
			} else {

				$options = get_option( 'teamof_elegant_login_options' );

				wp_send_json_success([
					'redirect_url' => $options["login_redirect_url"]
				]);

			}

			return;
		}

	}

	public function get_register_ajax_request() {

        $options = get_option( 'teamof_elegant_register_options' );

		if(isset($_REQUEST)) {
			
			if(!validate_username($_REQUEST['of-register-username'])) {
				wp_send_json_error([
					'message' => __('Username validation error','of-elegant-auth')
				]);
			}

			if(!$this->validate_password($_REQUEST['of-password-email'])) {
				wp_send_json_error([
					'message' => __('Password validation error','of-elegant-auth')
				]);
			}

			if(!$this->validate_email($_REQUEST['of-register-email'])) {
				wp_send_json_error([
					'message' => __('Email is invalid','of-elegant-auth')
				]);
			}

			$user_id = username_exists( $_REQUEST['of-register-username'] );
            
            if($user_id) 
                wp_send_json_error([
                    'message' => __('Username already taken','of-elegant-auth')
                ]);

			if (!$user_id && email_exists($_REQUEST['of-register-email']) == false) {

				$user_id = wp_create_user( $_REQUEST['of-register-username'], $_REQUEST['of-register-passsword'], $_REQUEST['of-register-email'] );

				if(is_wp_error($user_id)) {
					wp_send_json_error([
                        'message' => __('WordPress error occured','of-elegant-auth'),
                        'dev_error_message' => $user_id->get_error_message()
					]);
				} else {
					wp_send_json_success([
                        'message' => __('Registration complete. please check your email','of-elegant-auth'),
                        'redirect_url' => $options["register_redirect_url"]
					]);
				}
			}

			wp_send_json_error([
				'message' => __('Wordpress error occured!','of-elegant-auth')
			]);

		}

		return;

	}

	public function get_forgot_ajax_request() {

		$user = get_user_by('email', $_REQUEST['of-forgot-email']);

		if(!$user) {

			wp_send_json_error([
				'message' => 'User not found'
			]);

			return;
		}

		$firstname = $user->first_name;
		$email = $user->user_email;
		$adt_rp_key = get_password_reset_key( $user );
		$user_login = $user->user_login;
		$rp_link = '<a href="' . wp_login_url()."/resetpass/?key=$adt_rp_key&login=" . rawurlencode($user_login) . '">' . wp_login_url()."/resetpass/?key=$adt_rp_key&login=" . rawurlencode($user_login) . '</a>';

		if ($firstname == "") $firstname = "gebruiker";
		$message = "Hi ".$firstname.",<br>";
		$message .= "An account has been created on ".get_bloginfo( 'name' )." for email address ".$email."<br>";
		$message .= "Click here to set the password for your account: <br>";
		$message .= $rp_link.'<br>';

		//deze functie moet je zelf nog toevoegen. 
		$subject = __("Your account on ".get_bloginfo( 'name'));
		$headers = array();

		add_filter( 'wp_mail_content_type', function( $content_type ) {return 'text/html';});
		$headers[] = 'From: Your company name <info@your-domain.com>'."\r\n";
		$sent = wp_mail( $email, $subject, $message, $headers);

		// Reset content-type to avoid conflicts -- http://core.trac.wordpress.org/ticket/23578
		remove_filter( 'wp_mail_content_type', 'set_html_content_type' );

		if($sent) {

			wp_send_json_success([
				'message' => "Recovery email has been sent"
			]);
				
			return;
		}

		wp_send_json_error([
			'message' => 'Something wrong'
		]);

	}

	public function validate_email($email) {
		
		if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
			return false;
		}
		
		return true;

	}

	public function validate_password($password) {

		if(preg_match("/^.*(?=.{8,})(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z]).*$/", $_REQUEST["of-register-password"]) === 0) {
			return false;
		}

		return true;

	}

}