(function( $ ) {

	(function (root, factory) {
		if (typeof define === 'function' && define.amd) {
		  // AMD support:
		  define([], factory);
		} else if (typeof module === 'object' && module.exports) {
		  // CommonJS-like:
		  module.exports = factory();
		} else {
		  // Browser globals (root is window)
		  var bsn = factory();
		  root.Modal = bsn.Modal;
		}
	  }(this, function () {
	  
		"use strict";
	  
		// globals
		var globalObject = typeof global !== 'undefined' ? global : this||window,
		  DOC = document, HTML = DOC.documentElement, body = 'body', // allow the library to be used in <head>
	  
		  BSN = globalObject.BSN = {},
		  supports = BSN.supports = [],
	  
		  // function toggle attributes
		  dataToggle    = 'data-toggle',
		  dataDismiss   = 'data-dismiss',
		  dataSpy       = 'data-spy',
		  dataRide      = 'data-ride',
	  
		  // components
		  stringAlert     = 'Alert',
		  stringButton    = 'Button',
		  stringCarousel  = 'Carousel',
		  stringCollapse  = 'Collapse',
		  stringDropdown  = 'Dropdown',
		  stringModal     = 'Modal',
		  stringPopover   = 'Popover',
		  stringScrollSpy = 'ScrollSpy',
		  stringTab       = 'Tab',
		  stringTooltip   = 'Tooltip',
	  
		  // options DATA API
		  databackdrop      = 'data-backdrop',
		  dataKeyboard      = 'data-keyboard',
		  dataTarget        = 'data-target',
		  dataInterval      = 'data-interval',
		  dataHeight        = 'data-height',
		  dataPause         = 'data-pause',
		  dataTitle         = 'data-title',
		  dataOriginalTitle = 'data-original-title',
		  dataOriginalText  = 'data-original-text',
		  dataDismissible   = 'data-dismissible',
		  dataTrigger       = 'data-trigger',
		  dataAnimation     = 'data-animation',
		  dataContainer     = 'data-container',
		  dataPlacement     = 'data-placement',
		  dataDelay         = 'data-delay',
		  dataOffsetTop     = 'data-offset-top',
		  dataOffsetBottom  = 'data-offset-bottom',
	  
		  // option keys
		  backdrop = 'backdrop', keyboard = 'keyboard', delay = 'delay',
		  content = 'content', target = 'target',
		  interval = 'interval', pause = 'pause', animation = 'animation',
		  placement = 'placement', container = 'container',
	  
		  // box model
		  offsetTop    = 'offsetTop',      offsetBottom   = 'offsetBottom',
		  offsetLeft   = 'offsetLeft',
		  scrollTop    = 'scrollTop',      scrollLeft     = 'scrollLeft',
		  clientWidth  = 'clientWidth',    clientHeight   = 'clientHeight',
		  offsetWidth  = 'offsetWidth',    offsetHeight   = 'offsetHeight',
		  innerWidth   = 'innerWidth',     innerHeight    = 'innerHeight',
		  scrollHeight = 'scrollHeight',   height         = 'height',
	  
		  // aria
		  ariaExpanded = 'aria-expanded',
		  ariaHidden   = 'aria-hidden',
	  
		  // event names
		  clickEvent    = 'click',
		  hoverEvent    = 'hover',
		  keydownEvent  = 'keydown',
		  keyupEvent    = 'keyup',
		  resizeEvent   = 'resize',
		  scrollEvent   = 'scroll',
		  // originalEvents
		  showEvent     = 'show',
		  shownEvent    = 'shown',
		  hideEvent     = 'hide',
		  hiddenEvent   = 'hidden',
		  closeEvent    = 'close',
		  closedEvent   = 'closed',
		  slidEvent     = 'slid',
		  slideEvent    = 'slide',
		  changeEvent   = 'change',
	  
		  // other
		  getAttribute           = 'getAttribute',
		  setAttribute           = 'setAttribute',
		  hasAttribute           = 'hasAttribute',
		  createElement          = 'createElement',
		  appendChild            = 'appendChild',
		  innerHTML              = 'innerHTML',
		  getElementsByTagName   = 'getElementsByTagName',
		  preventDefault         = 'preventDefault',
		  getBoundingClientRect  = 'getBoundingClientRect',
		  querySelectorAll       = 'querySelectorAll',
		  getElementsByCLASSNAME = 'getElementsByClassName',
		  getComputedStyle       = 'getComputedStyle',
	  
		  indexOf      = 'indexOf',
		  parentNode   = 'parentNode',
		  length       = 'length',
		  toLowerCase  = 'toLowerCase',
		  Transition   = 'Transition',
		  Duration     = 'Duration',
		  Webkit       = 'Webkit',
		  style        = 'style',
		  push         = 'push',
		  tabindex     = 'tabindex',
		  contains     = 'contains',
	  
		  active     = 'active',
		  showClass  = 'show',
		  collapsing = 'collapsing',
		  disabled   = 'disabled',
		  loading    = 'loading',
		  left       = 'left',
		  right      = 'right',
		  top        = 'top',
		  bottom     = 'bottom',
	  
		  // tooltip / popover
		  mouseHover = ('onmouseleave' in DOC) ? [ 'mouseenter', 'mouseleave'] : [ 'mouseover', 'mouseout' ],
		  tipPositions = /\b(top|bottom|left|right)+/,
	  
		  // modal
		  modalOverlay = 0,
		  fixedTop = 'fixed-top',
		  fixedBottom = 'fixed-bottom',
	  
		  // transitionEnd since 2.0.4
		  supportTransitions = Webkit+Transition in HTML[style] || Transition[toLowerCase]() in HTML[style],
		  transitionEndEvent = Webkit+Transition in HTML[style] ? Webkit[toLowerCase]()+Transition+'End' : Transition[toLowerCase]()+'end',
		  transitionDuration = Webkit+Duration in HTML[style] ? Webkit[toLowerCase]()+Transition+Duration : Transition[toLowerCase]()+Duration,
	  
		  // set new focus element since 2.0.3
		  setFocus = function(element){
			element.focus ? element.focus() : element.setActive();
		  },
	  
		  // class manipulation, since 2.0.0 requires polyfill.js
		  addClass = function(element,classNAME) {
			element.classList.add(classNAME);
		  },
		  removeClass = function(element,classNAME) {
			element.classList.remove(classNAME);
		  },
		  hasClass = function(element,classNAME){ // since 2.0.0
			return element.classList[contains](classNAME);
		  },
	  
		  // selection methods
		  getElementsByClassName = function(element,classNAME) { // returns Array
			return [].slice.call(element[getElementsByCLASSNAME]( classNAME ));
		  },
		  queryElement = function (selector, parent) {
			var lookUp = parent ? parent : DOC;
			return typeof selector === 'object' ? selector : lookUp.querySelector(selector);
		  },
		  getClosest = function (element, selector) { //element is the element and selector is for the closest parent element to find
			// source http://gomakethings.com/climbing-up-and-down-the-dom-tree-with-vanilla-javascript/
			var firstChar = selector.charAt(0), selectorSubstring = selector.substr(1);
			if ( firstChar === '.' ) {// If selector is a class
			  for ( ; element && element !== DOC; element = element[parentNode] ) { // Get closest match
				if ( queryElement(selector,element[parentNode]) !== null && hasClass(element,selectorSubstring) ) { return element; }
			  }
			} else if ( firstChar === '#' ) { // If selector is an ID
			  for ( ; element && element !== DOC; element = element[parentNode] ) { // Get closest match
				if ( element.id === selectorSubstring ) { return element; }
			  }
			}
			return false;
		  },
	  
		  // event attach jQuery style / trigger  since 1.2.0
		  on = function (element, event, handler) {
			element.addEventListener(event, handler, false);
		  },
		  off = function(element, event, handler) {
			element.removeEventListener(event, handler, false);
		  },
		  one = function (element, event, handler) { // one since 2.0.4
			on(element, event, function handlerWrapper(e){
			  handler(e);
			  off(element, event, handlerWrapper);
			});
		  },
		  getTransitionDurationFromElement = function(element) {
			var duration = globalObject[getComputedStyle](element)[transitionDuration];
			duration = parseFloat(duration);
			duration = typeof duration === 'number' && !isNaN(duration) ? duration * 1000 : 0;
			return duration + 50; // we take a short offset to make sure we fire on the next frame after animation
		  },
		  emulateTransitionEnd = function(element,handler){ // emulateTransitionEnd since 2.0.4
			var called = 0, duration = getTransitionDurationFromElement(element);
			supportTransitions && one(element, transitionEndEvent, function(e){ handler(e); called = 1; });
			setTimeout(function() { !called && handler(); }, duration);
		  },
		  bootstrapCustomEvent = function (eventName, componentName, related) {
			var OriginalCustomEvent = new CustomEvent( eventName + '.bs.' + componentName);
			OriginalCustomEvent.relatedTarget = related;
			this.dispatchEvent(OriginalCustomEvent);
		  },
	  
		  // tooltip / popover stuff
		  getScroll = function() { // also Affix and ScrollSpy uses it
			return {
			  y : globalObject.pageYOffset || HTML[scrollTop],
			  x : globalObject.pageXOffset || HTML[scrollLeft]
			}
		  },
		  styleTip = function(link,element,position,parent) { // both popovers and tooltips (target,tooltip,placement,elementToAppendTo)
			var elementDimensions = { w : element[offsetWidth], h: element[offsetHeight] },
				windowWidth = (HTML[clientWidth] || DOC[body][clientWidth]),
				windowHeight = (HTML[clientHeight] || DOC[body][clientHeight]),
				rect = link[getBoundingClientRect](),
				scroll = parent === DOC[body] ? getScroll() : { x: parent[offsetLeft] + parent[scrollLeft], y: parent[offsetTop] + parent[scrollTop] },
				linkDimensions = { w: rect[right] - rect[left], h: rect[bottom] - rect[top] },
				isPopover = hasClass(element,'popover'),
				topPosition, leftPosition,
	  
				arrow = queryElement('.arrow',element),
				arrowTop, arrowLeft, arrowWidth, arrowHeight,
	  
				halfTopExceed = rect[top] + linkDimensions.h/2 - elementDimensions.h/2 < 0,
				halfLeftExceed = rect[left] + linkDimensions.w/2 - elementDimensions.w/2 < 0,
				halfRightExceed = rect[left] + elementDimensions.w/2 + linkDimensions.w/2 >= windowWidth,
				halfBottomExceed = rect[top] + elementDimensions.h/2 + linkDimensions.h/2 >= windowHeight,
				topExceed = rect[top] - elementDimensions.h < 0,
				leftExceed = rect[left] - elementDimensions.w < 0,
				bottomExceed = rect[top] + elementDimensions.h + linkDimensions.h >= windowHeight,
				rightExceed = rect[left] + elementDimensions.w + linkDimensions.w >= windowWidth;
	  
			// recompute position
			position = (position === left || position === right) && leftExceed && rightExceed ? top : position; // first, when both left and right limits are exceeded, we fall back to top|bottom
			position = position === top && topExceed ? bottom : position;
			position = position === bottom && bottomExceed ? top : position;
			position = position === left && leftExceed ? right : position;
			position = position === right && rightExceed ? left : position;
	  
			// update tooltip/popover class
			element.className[indexOf](position) === -1 && (element.className = element.className.replace(tipPositions,position));
	  
			// we check the computed width & height and update here
			arrowWidth = arrow[offsetWidth]; arrowHeight = arrow[offsetHeight];
	  
			// apply styling to tooltip or popover
			if ( position === left || position === right ) { // secondary|side positions
			  if ( position === left ) { // LEFT
				leftPosition = rect[left] + scroll.x - elementDimensions.w - ( isPopover ? arrowWidth : 0 );
			  } else { // RIGHT
				leftPosition = rect[left] + scroll.x + linkDimensions.w;
			  }
	  
			  // adjust top and arrow
			  if (halfTopExceed) {
				topPosition = rect[top] + scroll.y;
				arrowTop = linkDimensions.h/2 - arrowWidth;
			  } else if (halfBottomExceed) {
				topPosition = rect[top] + scroll.y - elementDimensions.h + linkDimensions.h;
				arrowTop = elementDimensions.h - linkDimensions.h/2 - arrowWidth;
			  } else {
				topPosition = rect[top] + scroll.y - elementDimensions.h/2 + linkDimensions.h/2;
				arrowTop = elementDimensions.h/2 - (isPopover ? arrowHeight*0.9 : arrowHeight/2);
			  }
			} else if ( position === top || position === bottom ) { // primary|vertical positions
			  if ( position === top) { // TOP
				topPosition =  rect[top] + scroll.y - elementDimensions.h - ( isPopover ? arrowHeight : 0 );
			  } else { // BOTTOM
				topPosition = rect[top] + scroll.y + linkDimensions.h;
			  }
			  // adjust left | right and also the arrow
			  if (halfLeftExceed) {
				leftPosition = 0;
				arrowLeft = rect[left] + linkDimensions.w/2 - arrowWidth;
			  } else if (halfRightExceed) {
				leftPosition = windowWidth - elementDimensions.w*1.01;
				arrowLeft = elementDimensions.w - ( windowWidth - rect[left] ) + linkDimensions.w/2 - arrowWidth/2;
			  } else {
				leftPosition = rect[left] + scroll.x - elementDimensions.w/2 + linkDimensions.w/2;
				arrowLeft = elementDimensions.w/2 - arrowWidth/2;
			  }
			}
	  
			// apply style to tooltip/popover and its arrow
			element[style][top] = topPosition + 'px';
			element[style][left] = leftPosition + 'px';
	  
			arrowTop && (arrow[style][top] = arrowTop + 'px');
			arrowLeft && (arrow[style][left] = arrowLeft + 'px');
		  };
	  
		BSN.version = '2.0.24';
	  
		// MODAL DEFINITION
		// ===============
		var Modal = function(element, options) { // element can be the modal/triggering button
	  
		  // the modal (both JavaScript / DATA API init) / triggering button element (DATA API)
		  element = queryElement(element);
	  
		  // determine modal, triggering element
		  var btnCheck = element[getAttribute](dataTarget)||element[getAttribute]('href'),
			checkModal = queryElement( btnCheck ),
			modal = hasClass(element,'modal') ? element : checkModal,
			overlayDelay,
	  
			// strings
			component = 'modal',
			staticString = 'static',
			paddingLeft = 'paddingLeft',
			paddingRight = 'paddingRight',
			modalBackdropString = 'modal-backdrop';
	  
		  if ( hasClass(element,'modal') ) { element = null; } // modal is now independent of it's triggering element
	  
		  if ( !modal ) { return; } // invalidate
	  
		  // set options
		  options = options || {};
	  
		  this[keyboard] = options[keyboard] === false || modal[getAttribute](dataKeyboard) === 'false' ? false : true;
		  this[backdrop] = options[backdrop] === staticString || modal[getAttribute](databackdrop) === staticString ? staticString : true;
		  this[backdrop] = options[backdrop] === false || modal[getAttribute](databackdrop) === 'false' ? false : this[backdrop];
		  this[content]  = options[content]; // JavaScript only
	  
		  // bind, constants, event targets and other vars
		  var self = this, relatedTarget = null,
			bodyIsOverflowing, modalIsOverflowing, scrollbarWidth, overlay,
	  
			// also find fixed-top / fixed-bottom items
			fixedItems = getElementsByClassName(HTML,fixedTop).concat(getElementsByClassName(HTML,fixedBottom)),
	  
			// private methods
			getWindowWidth = function() {
			  var htmlRect = HTML[getBoundingClientRect]();
			  return globalObject[innerWidth] || (htmlRect[right] - Math.abs(htmlRect[left]));
			},
			setScrollbar = function () {
			  var bodyStyle = globalObject[getComputedStyle](DOC[body]),
				  bodyPad = parseInt((bodyStyle[paddingRight]), 10), itemPad;
			  if (bodyIsOverflowing) {
				DOC[body][style][paddingRight] = (bodyPad + scrollbarWidth) + 'px';
				if (fixedItems[length]){
				  for (var i = 0; i < fixedItems[length]; i++) {
					itemPad = globalObject[getComputedStyle](fixedItems[i])[paddingRight];
					fixedItems[i][style][paddingRight] = ( parseInt(itemPad) + scrollbarWidth) + 'px';
				  }
				}
			  }
			},
			resetScrollbar = function () {
			  DOC[body][style][paddingRight] = '';
			  if (fixedItems[length]){
				for (var i = 0; i < fixedItems[length]; i++) {
				  fixedItems[i][style][paddingRight] = '';
				}
			  }
			},
			measureScrollbar = function () { // thx walsh
			  var scrollDiv = DOC[createElement]('div'), scrollBarWidth;
			  scrollDiv.className = component+'-scrollbar-measure'; // this is here to stay
			  DOC[body][appendChild](scrollDiv);
			  scrollBarWidth = scrollDiv[offsetWidth] - scrollDiv[clientWidth];
			  DOC[body].removeChild(scrollDiv);
			  return scrollBarWidth;
			},
			checkScrollbar = function () {
			  bodyIsOverflowing = DOC[body][clientWidth] < getWindowWidth();
			  modalIsOverflowing = modal[scrollHeight] > HTML[clientHeight];
			  scrollbarWidth = measureScrollbar();
			},
			adjustDialog = function () {
			  modal[style][paddingLeft] = !bodyIsOverflowing && modalIsOverflowing ? scrollbarWidth + 'px' : '';
			  modal[style][paddingRight] = bodyIsOverflowing && !modalIsOverflowing ? scrollbarWidth + 'px' : '';
			},
			resetAdjustments = function () {
			  modal[style][paddingLeft] = '';
			  modal[style][paddingRight] = '';
			},
			createOverlay = function() {
			  modalOverlay = 1;
	  
			  var newOverlay = DOC[createElement]('div');
			  overlay = queryElement('.'+modalBackdropString);
	  
			  if ( overlay === null ) {
				newOverlay[setAttribute]('class',modalBackdropString+' fade');
				overlay = newOverlay;
				DOC[body][appendChild](overlay);
			  }
			},
			removeOverlay = function() {
			  overlay = queryElement('.'+modalBackdropString);
			  if ( overlay && overlay !== null && typeof overlay === 'object' ) {
				modalOverlay = 0;
				DOC[body].removeChild(overlay); overlay = null;
			  }
			  bootstrapCustomEvent.call(modal, hiddenEvent, component);
			},
			keydownHandlerToggle = function() {
			  if (hasClass(modal,showClass)) {
				on(DOC, keydownEvent, keyHandler);
			  } else {
				off(DOC, keydownEvent, keyHandler);
			  }
			},
			resizeHandlerToggle = function() {
			  if (hasClass(modal,showClass)) {
				on(globalObject, resizeEvent, self.update);
			  } else {
				off(globalObject, resizeEvent, self.update);
			  }
			},
			dismissHandlerToggle = function() {
			  if (hasClass(modal,showClass)) {
				on(modal, clickEvent, dismissHandler);
			  } else {
				off(modal, clickEvent, dismissHandler);
			  }
			},
			// triggers
			triggerShow = function() {
			  setFocus(modal);
			  bootstrapCustomEvent.call(modal, shownEvent, component, relatedTarget);
			},
			triggerHide = function() {
			  modal[style].display = '';
			  element && (setFocus(element));
	  
			  (function(){
				if (!getElementsByClassName(DOC,component+' '+showClass)[0]) {
				  resetAdjustments();
				  resetScrollbar();
				  removeClass(DOC[body],component+'-open');
				  overlay && hasClass(overlay,'fade') ? (removeClass(overlay,showClass), emulateTransitionEnd(overlay,removeOverlay))
				  : removeOverlay();
	  
				  resizeHandlerToggle();
				  dismissHandlerToggle();
				  keydownHandlerToggle();
				}
			  }());
			},
			// handlers
			clickHandler = function(e) {
			  var clickTarget = e[target];
			  clickTarget = clickTarget[hasAttribute](dataTarget) || clickTarget[hasAttribute]('href') ? clickTarget : clickTarget[parentNode];
			  if ( clickTarget === element && !hasClass(modal,showClass) ) {
				modal.modalTrigger = element;
				relatedTarget = element;
				self.show();
				e[preventDefault]();
			  }
			},
			keyHandler = function(e) {
			  if (self[keyboard] && e.which == 27 && hasClass(modal,showClass)) {
				self.hide();
			  }
			},
			dismissHandler = function(e) {
			  var clickTarget = e[target];
			  if ( hasClass(modal,showClass) && (clickTarget[parentNode][getAttribute](dataDismiss) === component
				  || clickTarget[getAttribute](dataDismiss) === component
				  || (clickTarget === modal && self[backdrop] !== staticString) ) ) {
				self.hide(); relatedTarget = null;
				e[preventDefault]();
			  }
			};
	  
		  // public methods
		  this.toggle = function() {
			if ( hasClass(modal,showClass) ) {this.hide();} else {this.show();}
		  };
		  this.show = function() {
			bootstrapCustomEvent.call(modal, showEvent, component, relatedTarget);
	  
			// we elegantly hide any opened modal
			var currentOpen = getElementsByClassName(DOC,component+' '+showClass)[0];
			currentOpen && currentOpen !== modal && currentOpen.modalTrigger[stringModal].hide();
	  
			if ( this[backdrop] ) {
			  !modalOverlay && createOverlay();
			}
	  
			if ( overlay && modalOverlay && !hasClass(overlay,showClass)) {
			  overlay[offsetWidth]; // force reflow to enable trasition
			  overlayDelay = getTransitionDurationFromElement(overlay);
			  addClass(overlay, showClass);
			}
	  
			setTimeout( function() {
			  modal[style].display = 'block';
	  
			  checkScrollbar();
			  setScrollbar();
			  adjustDialog();
	  
			  addClass(DOC[body],component+'-open');
			  addClass(modal,showClass);
			  modal[setAttribute](ariaHidden, false);
	  
			  resizeHandlerToggle();
			  dismissHandlerToggle();
			  keydownHandlerToggle();
	  
			  hasClass(modal,'fade') ? emulateTransitionEnd(modal, triggerShow) : triggerShow();
			}, supportTransitions && overlay ? overlayDelay : 0);
		  };
		  this.hide = function() {
			bootstrapCustomEvent.call(modal, hideEvent, component);
			overlay = queryElement('.'+modalBackdropString);
			overlayDelay = overlay && getTransitionDurationFromElement(overlay);
	  
			removeClass(modal,showClass);
			modal[setAttribute](ariaHidden, true);
	  
			setTimeout(function(){
			  hasClass(modal,'fade') ? emulateTransitionEnd(modal, triggerHide) : triggerHide();
			}, supportTransitions && overlay ? overlayDelay : 0);
		  };
		  this.setContent = function( content ) {
			queryElement('.'+component+'-content',modal)[innerHTML] = content;
		  };
		  this.update = function() {
			if (hasClass(modal,showClass)) {
			  checkScrollbar();
			  setScrollbar();
			  adjustDialog();
			}
		  };
	  
		  // init
		  // prevent adding event handlers over and over
		  // modal is independent of a triggering element
		  if ( !!element && !(stringModal in element) ) {
			on(element, clickEvent, clickHandler);
		  }
		  if ( !!self[content] ) { self.setContent( self[content] ); }
		  !!element && (element[stringModal] = self);
		};
	  
		// DATA API
		supports[push]( [ stringModal, Modal, '['+dataToggle+'="modal"]' ] );
	  
		var initializeDataAPI = function( constructor, collection ){
			for (var i=0, l=collection[length]; i<l; i++) {
			  new constructor(collection[i]);
			}
		  },
		  initCallback = BSN.initCallback = function(lookUp){
			lookUp = lookUp || DOC;
			for (var i=0, l=supports[length]; i<l; i++) {
			  initializeDataAPI( supports[i][1], lookUp[querySelectorAll] (supports[i][2]) );
			}
		  };
	  
		// bulk initialize all components
		DOC[body] ? initCallback() : on( DOC, 'DOMContentLoaded', function(){ initCallback(); } );
	  
		return {
		  Modal: Modal
		};
	  }));
	
	  (function() {
	
		document.addEventListener("DOMContentLoaded", function(event) {
			
	
		class OF_Elegant_Modal {
	
			static get PASSWORD_TOGGLE_CLASSES() {
				return [
					{
						btn: "lpassword-toggle-btn",
						input: "of-login-password"
					},
					{ 
						btn:"rpassword-toggle-btn",
						input: "of-register-password"
					}
				]
			}
		
			get PASSWORD_TOGGLE_CLASSES() {
		
				
				var triggers = this.constructor.PASSWORD_TOGGLE_CLASSES
		
				var triggers_nodes = []
		
				for(let i=0; i < triggers.length; i++) {
		
					let node = {
		
						btn_node: document.querySelector("."+triggers[i].btn),
		
						input_node: document.querySelector("."+triggers[i].input)
			
					}
					
					triggers_nodes.push(node)
				   
				}
		
				return triggers_nodes
			}
		
			get login_states() {
				return this._login_states
			}
		
			set login_states(values) {
				this._login_states = values
			}
		
			get forgot_state() {
				return this._forgot_state
			}
		
			set forgot_state(values) {
				this._forgot_state = values
			}
		
			get register_states() {
				return this._register_states
			}
		
			set register_states(values) {
				this._register_states = values
			}
			
			constructor() {
		
				this._login_states = {
					email: false,
					password: false
				}
		
				this._forgot_state = {
					email: false
				}
		
				this._register_states = {
					username: false,
					email: false,
					lowercase: false,
					one_number: false,
					uppercase: false,
					min_chars: false
				}
		
				//form containers
				
				this.login_container = document.querySelector(".of-login-container")
				this.forgot_container = document.querySelector(".of-forgot-container")
				this.register_container = document.querySelector(".of-register-container")
		
				//email inputs

				this.email_inputs = document.querySelectorAll(".of-elegant-modal .of-email-validate")
		
				// pair toggle link

				this.pair_toggle_node = document.querySelectorAll(".of-toggle-link")
		
				 // forgot pair link

				this.forgot_toggle_node = document.querySelectorAll(".of-forgot-link")
		
				//login btn

				this.of_login_btn = document.querySelector(".of-login-btn")
		
				//forgot btn

				this.of_forgot_btn = document.querySelector(".of-forgot-btn")
		
				//register btn

				this.of_register_btn = document.querySelector(".of-register-btn")
		
				// tip nodes

				this.lowercase_tip = document.querySelector(".of-lowercase-tip")
				this.one_number_tip = document.querySelector(".of-one-number-tip")
				this.uppercase_tip = document.querySelector(".of-uppercase-tip")
				this.min_chars_tip = document.querySelector(".of-8chars-tip")
				
				// captcha selector
				var captcha_container = document.querySelector(".of-captcha-container")

				// Watch Objects

				this.values = {}
		
				this.triggers = {}
		
		   
		
		
				// call actions
				
				if(!$('body').hasClass('logged-in')) {

					this.register_password_validation()
		
					this.email_validation()
			
					this.login_form_ready()
			
					this.register_form_ready()
			
					this.forgot_form_ready()
			
					this.toggle_password()
			
					this.pair_toggle_link_action()
					
					this.pair_forgot_toggle()

				}

				
				$(document).ajaxSend(function(){
					$(".of-btn").addClass('loading');
				});

				$(document).ajaxComplete(function(){
					$(".of-btn").removeClass('loading');
				});

				$(this.of_login_btn).on('click', (e) => {

					let username = $(".of-login-username").val()
					let user_password = $(".of-login-password").val()
					this.make_login_request(username,user_password, this.of_login_btn.getAttribute('of-captcha'))

				})


				$(this.of_register_btn).on('click', (e) => {
					
					let username = $("#of-register-username").val()
					let user_email = $("#of-register-email").val()
					let user_password = $("#of-register-password").val()

					this.make_register_request(username, user_email, user_password, this.of_register_btn.getAttribute('of-captcha'))

				})

				$(this.of_forgot_btn).on('click', (e) => {
					
					let user_email = $("#of-forgot-email").val()

					this.make_forgot_request(user_email, this.of_forgot_btn.getAttribute('of-captcha'))

				})

				let modal_link_trigger = $(".teamof-elegant-auth")

				if(modal_link_trigger.length) {

					modal_link_trigger.on('click', function(event) {
						event.preventDefault()
						new Modal(".of-elegant-modal").show()
					})
				}

                var grecaptcha_script = $('script[src*="https://www.google.com/recaptcha/api.js"]').length; 

                if(grecaptcha_script === 0) {
                    var head = document.getElementsByTagName('head')[0];
                    var script = document.createElement('script');
                    script.src = 'https://www.google.com/recaptcha/api.js';
                    head.appendChild(script);
                }

				$(captcha_container).on('click', function(e) {

					let container = $(".of-captcha-wrapper");

					if (!container.is(e.target) && container.has(e.target).length === 0) {

						$(captcha_container).css({
							'opacity': 0,
							'visibility': 'hidden'
						})

					}
				});

				$(".of-close").on('click', function() {

					$(captcha_container).css({
						'opacity': 0,
						'visibility': 'hidden'
					});

				});

			}
			
			_watch(key,element) {
				this._watch_set(key,element.value,element)
			}
		
			_watch_add(name,fn) {
				
				if (name.constructor === Array) {
		
					for (let index = 0; index < name.length; index++) {
						this._watch_add(name[index],fn)
					}
				}
		
		
				if (this.triggers[name] == undefined) {
					
					var self = this
					
					this.triggers[name] = []
		
					let target = document.getElementsByName(name)[0];
					
					['change', 'keyup', 'cut', 'paste'].forEach(event => 
		
						target.addEventListener(event,(e) => {
							this._watch(name,e.target)
						})
					
					)
		
				}
		
				this.triggers[name].push(fn)
		
				if (this.values[name]) {
					fn.call(this.values[name][1], this.values[name][0])
				}
		
			}
		
		
			_watch_set(key,val,el) {
		
				this.values[key] = [val, el]
		
				for (var k in this.triggers[key]) {
		
					this.triggers[key][k].call(el, val)
		
				}
			}
		
			
			username_validation() {

				var self = this
		
				this._watch_add('of-login-username', function(value) {

					let validation_element = $(".username-validation")
					
					if(value.length > 0) {
						validation_element.removeClass("invalid")
						validation_element.addClass("valid")
						self.of_login_btn.disabled = false
					} else {
						validation_element.removeClass("valid")
						validation_element.addClass("invalid")
						self.of_login_btn.disabled = true
					}
					
				})


				this._watch_add('of-register-username', function(value) {

					let validation_element = $(".register-username-validation")
					
					if(value.length > 0) {
						validation_element.removeClass("invalid")
						validation_element.addClass("valid")
						self._register_states.username = true
					} else {
						validation_element.removeClass("valid")
						validation_element.addClass("invalid")
						self._register_states.username = false
					}

				})

			}

			register_password_validation() {
		
				var self = this
		
				this._watch_add('of-register-password', function(value) {
					
					//Validate lowercase letters
					var lowerCaseLetters = /[a-z]/g;
					if(value.match(lowerCaseLetters)) {
						self.lowercase_tip.classList.add("done")
						self._register_states.lowercase = true
					} else {
						self.lowercase_tip.classList.remove("done")
						self._register_states.lowercase = false
					}
				
					// Validate numbers
					var numbers = /[0-9]/g;
					if(value.match(numbers)) { 
						self.one_number_tip.classList.add("done")
						self._register_states.one_number = true
					} else {
						self.one_number_tip.classList.remove("done")
						self._register_states.one_number = false
					}
				
					// Validate capital letters
					var upperCaseLetters = /[A-Z]/g;
					if(value.match(upperCaseLetters)) { 
						self.uppercase_tip.classList.add("done")
						self._register_states.uppercase = true
					} else {
						self.uppercase_tip.classList.remove("done")
						self._register_states.uppercase = false
					}
				
				
					// Validate length
					if(value.length >= 8) {
						self.min_chars_tip.classList.add("done")
						self._register_states.min_chars = true
					} else {
						self.min_chars_tip.classList.remove("done")
						self._register_states.min_chars = false
					}
				
				})
		
			}
			
			login_password_validation() {
		
				let input = document.querySelector("input.of-login-password")
		
				if(input && input.value.length > 7) {
					this._login_states.password = true
				} else {
					this._login_states.password = false
				}
		
			}
		
			register_form_ready() {
		
				var form_inputs = document.querySelectorAll(".of-register-container input")
		
				for(let i=0; i < form_inputs.length; i++) {
		
					['change', 'keyup', 'cut', 'paste'].forEach(event => 
						
						form_inputs[i].addEventListener(event,(e) => {

							this.username_validation()

							if(this.register_states.username && this.register_states.email &&
								this.register_states.lowercase && this.register_states.one_number &&
								this.register_states.uppercase && this.register_states.min_chars) {
								this.of_register_btn.disabled = false
							} else { 
								this.of_register_btn.disabled = true
							}
		
						})
					
					)
				}
		
			}
		
			login_form_ready() {
		
				var form_inputs = document.querySelectorAll(".of-login-container input")
		
				for(let i=0; i < form_inputs.length; i++) {
		
					['change', 'keyup', 'cut', 'paste'].forEach(event => 
						
						form_inputs[i].addEventListener(event,(e) => {
							
							this.username_validation()

						})
					
					)
				}
		
			}
		
			forgot_form_ready() {
		
				var form_inputs = document.querySelectorAll(".of-forgot-container input")
		
				for(let i=0; i < form_inputs.length; i++) {
		
					['change', 'keyup', 'cut', 'paste'].forEach(event => 
						
						form_inputs[i].addEventListener(event,(e) => {
							
							if(this.forgot_state.email) {
								this.of_forgot_btn.disabled = false
							} else { 
								this.of_forgot_btn.disabled = true
							}
		
						})
					
					)
				}
		
			}
		
			email_validation() {
		
				var self = this
		
				for(let i=0; i < self.email_inputs.length; i++) {
		
					self.email_inputs[i].onkeyup = () => {   
						var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
						
						if(re.test(String(self.email_inputs[i].value).toLowerCase())) {
		
							self.email_inputs[i].nextElementSibling.classList.remove("invalid")
							self.email_inputs[i].nextElementSibling.classList.add("valid")
							if(self.email_inputs[i].classList.contains("of-forgot-email")) {
								this._forgot_state.email = true
							} else if(self.email_inputs[i].classList.contains("of-register-email")) {
								this._register_states.email = true
							}
						} else {
							self.email_inputs[i].nextElementSibling.classList.remove("valid")
							self.email_inputs[i].nextElementSibling.classList.add("invalid")
							
						}
					}
				}
				
			}
		
			toggle_password() {
		
				let triggers = this.PASSWORD_TOGGLE_CLASSES
		
				for(let i=0; i < triggers.length; i++) {
		
					triggers[i].btn_node.addEventListener('click', () => {
		
						if(triggers[i].input_node.type == "password") {
		
							triggers[i].btn_node.classList.remove("show-password")
							triggers[i].btn_node.classList.add("hide-password")
							triggers[i].input_node.type = "text"
		
						} else if(triggers[i].input_node.type == "text") {
		
							triggers[i].btn_node.classList.remove("hide-password")
							triggers[i].btn_node.classList.add("show-password")
							triggers[i].input_node.type = "password"
		
						}
		
					})
				}
		
			}
		
			pair_toggle_link_action() {
		
				for(let i=0; i < this.pair_toggle_node.length; i++) {
					this.pair_toggle_node[i].addEventListener('click', () => {
						this.register_container.classList.toggle('of-show')
						this.login_container.classList.toggle('of-show')
					})
				}
		
			}
		
			pair_forgot_toggle() {
		
				for(let i=0; i < this.forgot_toggle_node.length; i++) {
					this.forgot_toggle_node[i].addEventListener('click', () => {
						this.forgot_container.classList.toggle('of-show')
						this.login_container.classList.toggle('of-show')
					})
				}
		
			}
			
			make_login_request(username, password, action) {

                if("captcha" == action) {
                    localStorage.setItem("teamof_form_action","login")
                    localStorage.setItem("teamof_login_username", username)
                    localStorage.setItem("teamof_login_password", password)
                    this.captcha()

                    return
                }

				var self = this

				$.ajax({
					url:  of_ajax_obj.ajaxurl,
					contentType: "application/json",
        			dataType: "json",
					data: {
						'action': 'get_login_ajax_request',
						'of-login-username': username,
						'of-login-password': password,
						'of-remember': true
					},
					success:function(data) {
                        self.notification('login', data)
                        localStorage.removeItem("teamof_login_username")
                        localStorage.removeItem("teamof_login_password")

					},
					error: function(errorThrown){
						console.log(errorThrown);
					}
				})

			}

			make_register_request(username, email, password, action) {

                if("captcha" == action) {
                    localStorage.setItem("teamof_form_action","register")
                    localStorage.setItem("teamof_register_username", username)
                    localStorage.setItem("teamof_register_email", email)
                    localStorage.setItem("teamof_register_password", password)
                    this.captcha()

                    return
                }

				var self = this

				$.ajax({
					url:  of_ajax_obj.ajaxurl,
					contentType: "application/json",
        			dataType: "json",
					data: {
						'action': 'get_register_ajax_request',
						'of-register-username': username,
						'of-register-email': email,
						'of-register-password': password
					},
					success:function(data) {
							self.notification('register', data);
							localStorage.removeItem("teamof_register_username")
							localStorage.removeItem("teamof_register_email")
							localStorage.removeItem("teamof_register_password")
							if(data.dev_error_message) {
								console.log(data.dev_error_message)
							}
					},
					error: function(errorThrown){
						console.log(errorThrown);
					}
				})

			}

			make_forgot_request(email) {

				if("captcha" == action) {
                    localStorage.setItem("teamof_form_action","forgot")
                    localStorage.setItem("teamof_login_email", email)
                    this.captcha()

                    return
				}
				
				var self = this

				$.ajax({
					url:  of_ajax_obj.ajaxurl,
					contentType: "application/json",
        			dataType: "json",
					data: {
						'action': 'get_forgot_ajax_request',
						'of-forgot-email': email
					},
					success:function(data) {
						self.notification('forgot', data)
					},
					error: function(errorThrown){
						console.log(errorThrown);
					}
				})


			}

			notification(type, response) {

				if('register' == type) {
					let btn = $(".of-register-btn")

					let styles = {
						"pointer-events": "none"
					}

					if(!response.success) {
						styles["background-color"] = "red"
					} else {
							styles["font-size"] = "0.7rem"
							btn.text(response.data.message)
							btn.css(styles)

							if(response.data.redirect_url) {
									
									setTimeout(function(){
											btn.text("Redirecting...")
											window.location = response.data.redirect_url
									}, 1500)

									return
							}

					}					
					
					setTimeout(function() {
						btn.css({
							"background-color": "#2ecc71",
							"pointer-events": "auto",
							"font-size": "1.1em"
						})
						btn.text("Get Started")
					},
					3000)

					return 
				}
				
				if('login' == type) {
					let btn = $(".of-login-btn")

					let styles = {
						"pointer-events": "none"
					}

					if(!response.success) {
						styles["background-color"] = "red"
						btn.css(styles)
						btn.text(response.data.message)
					} else {
						btn.text("Redirecting...")
						window.location = response.data.redirect_url
					}
					
					setTimeout(function() {
						btn.css({
							"background-color": "#55a8fd",
							"pointer-events": "auto",
						})
						btn.text("Sign In")
					},
					3000)

					return

				}
				
				if('forgot' == type) { 

					let btn = $(".of-forgot-btn")

					let styles = {
						"pointer-events": "none"
					}

					if(!response.success) {
						styles["background-color"] = "red"
						btn.css(styles)
					}

					btn.text(response.data.message)

					setTimeout(function() {
						btn.css({
							"background-color": "#2ecc71",
							"pointer-events": "auto",
						})
						btn.text("Send Password")
					},
					3000)

					return

				}

			}

            captcha() {

                $(".of-captcha-container").css({
					'visibility': 'visible',
					'opacity': 1
				});
				
				grecaptcha.reset()

            }
            teamof_trigger() {
                
                if(localStorage.getItem("teamof_form_action") == "login") {
                    this.make_login_request(localStorage.getItem("teamof_login_username"),
                    localStorage.getItem("teamof_login_password"),"bypass")
                    return
                }

                if(localStorage.getItem("teamof_form_action") == "register") {
                    this.make_register_request(localStorage.getItem("teamof_register_username"),
                    localStorage.getItem("teamof_register_email"),
                    localStorage.getItem("teamof_register_password"),"bypass")
                    return
				}
				
				if(localStorage.getItem("teamof_form_action") == "forgot") {
                    this.make_forgot_request(localStorage.getItem("teamof_forgot_email"),"bypass")
                    return
                }

            }
		}
		
        const OF_Modal = new OF_Elegant_Modal()
        
        window.teamof = function() {
            OF_Modal.teamof_trigger()
        }
		
		}) // DOMLoaded
	
	})()
	
	
})( jQuery );
